﻿# Adaptive Images add-on for Optimizely

## DOCUMENTATION

When add-on is installed and enabled, documentation is available in the help menu (question mark icon) in the global navigation of the Optimizely UI.

To enable the addon, invoke something like the follwing in your `Startup` class:

```
public void ConfigureServices(IServiceCollection services)
{
    services.AddCms()
            .AddAdaptiveImages(); // Enable the add-on
}
```

**NOTE:** Developer documentation is only available when in debug mode, or when logged in as an administrator.

## IMAGE PROVIDERS

To test with an external image provider, you may install the "AdaptiveImages.Unsplash" NuGet package and enable it in your `Startup` class:

```
public void ConfigureServices(IServiceCollection services)
{
    services.AddCms();
            .AddAdaptiveImages();
            .AddUnsplash(); // Enable the Unsplash image provider
}
```

When at least one searchable image provider is added, the "Image bank" tab is displayed in the edit UI. Note that you may need to "Reset views"
in user settings for the component to appear.

## UPGRADING FROM 1.X
* Remove old package (TedGustaf.Episerver.AdaptiveImages) and remove the `\\modules\\_protected\\TedGustaf.Episerver.AdaptiveImages` folder and any app settings from web.config
* Install new package (AdaptiveImages) and enable the addon as described above, optionally passing settings to the `AddAdaptiveImages()` method
* Change any references to the `TedGustaf.Episerver.AdaptiveImages` namespace to simply `AdaptiveImages`
* If you run into problems with model synchronization, you may need to set `ModelType` to null in `tblContentType` in the database for the `SingleImage` and `AdaptiveImage` types (currently being investigated as a bug in the CMS) and restart the website (this is because of the namespace change for the content types)
* Refer to the integrated documentation on how to configure the add-on in your `Startup` class

## SUPPORT

Visit https://adaptiveimages.net or send e-mail to: support@tedgustaf.com
@tedgustaf and @tednyberg are also active on Twitter for any questions or feedback.

## CHANGE LOG
| Version  | Summary |
| ------------- | ------------- |
| 2.0.2.29 | Support for multiple proportions formats, explicit focal points, additional rendering options. |
| 2.0.0 | .NET 5 / CMS 12 support, disk cache. |
| 1.2.2021.05210 | Rendering quality settings to override auto. |
| 1.2.2021.03300 | Progressive encoding and quality options can be set through ImageRenderSettings for URL providers that support it. Improved crop dialog performance for large images. |
| 1.2.2021.01110 | Ability to show original image ID in the crop dialog. |
| 1.2.2020.11171 | Requirement on Episerver 11.20.2 or above because of Episerver bug CMS-17430 regarding proxy generation which affected globalization features. |
| 1.2.2020.10202 | Support for lazy loading. |
| 1.2.2020.10050 | Fixed isses with incorrect default rendering widths when using PropertyFor. |
| 1.1.2020.09191 | Improved behavior in cropping dialog when cropping near edges. |
| 1.1.2020.09092 | Support for image properties on POCO objects for IList<T> properties, using base classes ImagePropertyList/ImagePropertyListEditorDescriptor/AdaptiveImagePropertyListItem/SingleImagePropertyListItem, and SingleImageConverter/AdaptiveImageConverter JSON converters for any additional image properties on the list item type. |
| 1.1.2020.08280 | TinyMCE plugin handles standard insert image dialog, offering user to convert Episerver image to adaptive image. |
| 1.1.2020.08273 | TinyMCE plugin handles native Episerver images (drag and dropped from the "Media" component) as adaptive images. |
| 1.1.2020.08140 | Support drag-and-drop of local image file, uploading the file to the current assets folder. |
| 1.1.2020.05280 | Support for required image properties (RequiredImage attribute). |
| 1.1.2020.05200 | Support for culture-specific image properties (CultureSpecificImage attribute). |
| 1.1.2020.05190 | Paging support for image providers. |
| 1.1.2020.05180 | Support for adaptive image descriptions (alt texts). |
| 1.1.2020.05130 | Support for single form factor image properties (SingleImage property type). |